/***********************************************************************
 simple1.cpp - Example showing the simplest way to get the contents of
 	a table with MySQL++.

 Copyright (c) 1998 by Kevin Atkinson, (c) 1999, 2000 and 2001 by
 MySQL AB, and (c) 2004, 2005 by Educational Technology Resources, Inc.
 Others may also hold copyrights on code in this file.  See the CREDITS
 file in the top directory of the distribution for details.

 This file is part of MySQL++.

 MySQL++ is free software; you can redistribute it and/or modify it
 under the terms of the GNU Lesser General Public License as published
 by the Free Software Foundation; either version 2.1 of the License, or
 (at your option) any later version.

 MySQL++ is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with MySQL++; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
 USA
***********************************************************************/

#include "util.h"

#include <mysql++.h>

#include <iostream>
#include <iomanip>

using namespace std;

int
main(int argc, char *argv[])
{
	// Wrap all MySQL++ interactions in one big try block, so any
	// errors are handled gracefully.
	try {
		// Connect to the sample database
		mysqlpp::Connection con(mysqlpp::use_exceptions);
		if (!connect_to_db(argc, argv, con)) {
			return 1;
		}

		// Retrieve the entire stock table from the database server
		// we're connected to, and print its contents out.
		mysqlpp::Query query = con.query();
		print_stock_table(query);
	}
	catch (mysqlpp::BadQuery& er) {
		// Handle any connection or query errors that
		cerr << "Error: " << er.what() << endl;
		return -1;
	}
	catch (mysqlpp::BadConversion& er) {
		// Handle bad conversions
		cerr << "Error: " << er.what() << "\"." << endl <<
				"retrieved data size: " << er.retrieved <<
				" actual data size: " << er.actual_size << endl;
		return -1;
	}
	catch (exception& er) {
		// Catch-all for any other standard C++ exceptions
		cerr << "Error: " << er.what() << endl;
		return -1;
	}

	return 0;
}
